%define lib_major       4
%define lib_name_orig   %mklibname ssh
%define lib_name        %mklibname ssh %{lib_major}
%define dev_name	%mklibname ssh -d

Summary:	C library to authenticate in a simple manner to one or more SSH servers
Name:		libssh
Version:	0.7.5
Release:	%mkrel 1
Epoch:		1
Group:		System/Libraries
License:	LGPLv2.1+
URL:		http://www.libssh.org
Source0:	http://git.libssh.org/projects/libssh.git/snapshot/%{name}-%{version}.tar.gz
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	openssl-devel
BuildRequires:	pkgconfig
BuildRequires:	zlib-devel
BuildRequires:	libgcrypt-devel
BuildRequires:	libpcap-devel

%description
The ssh library was designed to be used by programmers needing a working 
SSH implementation by the mean of a library. The complete control of the 
client is made by the programmer. With libssh, you can remotely execute 
programs, transfer files, use a secure and transparent tunnel for your 
remote programs. With its Secure FTP implementation, you can play with 
remote files easily, without third-party programs others than libcrypto 
(from openssl). libssh features :

    * Full C library functions for manipulating a client-side SSH
      connection
    * Lesser GPL licensing -SSH2 protocol compliant
    * Fully configurable sessions
    * Support for AES-128,AES-192,AES-256,blowfish, in cbc mode
    * Use multiple SSH connections in a same process, at same time
    * Use multiple channels in the same connection
    * Thread safety when using different sessions at same time
    * Basic but correct SFTP implementation (secure file transfer)
    * RSA and DSS server public key supported
    * Compression support (with zlib)
    * Public key (RSA and DSS), password and keyboard-interactive
      authentication
    * Complete documentation about its API
    * Runs and tested under amd64, x86, arm, sparc32, ppc under Linux,
      BSD, MacosX and Solaris
    * A developer listening to you
    * It's free (LGPL)!

#--------------------------------------------------------------------


%package -n	%{lib_name}
Summary:	Main library for %{name}
Group:		System/Libraries

%description -n	%{lib_name}
The ssh library was designed to be used by programmers needing a working
SSH implementation by the mean of a library. The complete control of the
client is made by the programmer. With libssh, you can remotely execute
programs, transfer files, use a secure and transparent tunnel for your
remote programs. With its Secure FTP implementation, you can play with
remote files easily, without third-party programs others than libcrypto
(from openssl).

%files -n %{lib_name}
%{_libdir}/*.so.%{lib_major}{,.*}

#--------------------------------------------------------------------

%package -n	%{dev_name}
Summary:	Development files for %{name}
Group:		System/Libraries
Requires:	%{lib_name} = %{epoch}:%{version}-%{release}
Provides:	ssh-devel = %{epoch}:%{version}-%{release}
Provides:	libssh-devel = %{epoch}:%{version}-%{release}

%description -n	%{dev_name}
This package contains the development files for %{name}.

%files -n %{dev_name}
%{_includedir}/%{name}
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/*

#--------------------------------------------------------------------

%prep
%setup -q
%autopatch -p1

%build
%cmake -DWITH_GCRYPT=ON -DWITH_PCAP=ON

%make

%install
%makeinstall_std -C build


%changelog
* Tue May 02 2017 luigiwalser <luigiwalser> 1:0.7.5-1.mga6
+ Revision: 1098253
- 0.7.5

* Sun Feb 12 2017 luigiwalser <luigiwalser> 1:0.7.4-1.mga6
+ Revision: 1085836
- 0.7.4

* Tue Feb 23 2016 pterjan <pterjan> 1:0.7.3-1.mga6
+ Revision: 977352
- Update to 0.7.3 (CVE-2016-0739)

* Fri Jan 01 2016 luigiwalser <luigiwalser> 1:0.7.2-1.mga6
+ Revision: 917797
- 0.7.2

* Thu Sep 10 2015 fwang <fwang> 1:0.6.5-2.mga6
+ Revision: 875366
- rebuild for new libgcrypt

* Wed May 06 2015 luigiwalser <luigiwalser> 1:0.6.5-1.mga5
+ Revision: 821333
- 0.6.5 (fixes CVE-2015-3146)
- remove upstreamed patches

* Mon Jan 05 2015 luigiwalser <luigiwalser> 1:0.6.4-1.mga5
+ Revision: 808703
- 0.6.4 (fixes CVE-2014-8132)
- add upstream patches to fix bug and build error

* Wed Oct 15 2014 umeabot <umeabot> 1:0.6.3-3.mga5
+ Revision: 747112
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:0.6.3-2.mga5
+ Revision: 681798
- Mageia 5 Mass Rebuild

* Wed Mar 05 2014 luigiwalser <luigiwalser> 1:0.6.3-1.mga5
+ Revision: 599978
- 0.6.3 (fixes CVE-2014-0017)

* Sat Feb 15 2014 dams <dams> 1:0.6.1-1.mga5
+ Revision: 591816
- new version 0.6.1

* Fri Jan 17 2014 luigiwalser <luigiwalser> 1:0.6.0-1.mga5
+ Revision: 566765
- 0.6.0

* Sat Oct 19 2013 umeabot <umeabot> 1:0.5.5-2.mga4
+ Revision: 530650
- Mageia 4 Mass Rebuild

* Fri Jul 26 2013 sander85 <sander85> 1:0.5.5-1.mga4
+ Revision: 458705
- New version: 0.5.5

* Tue Jan 29 2013 luigiwalser <luigiwalser> 1:0.5.4-1.mga3
+ Revision: 393089
- 0.5.4 (fixes CVE-2013-0176)

* Sat Jan 12 2013 umeabot <umeabot> 1:0.5.3-2.mga3
+ Revision: 358208
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Nov 26 2012 luigiwalser <luigiwalser> 1:0.5.3-1.mga3
+ Revision: 322162
- 0.5.3 (fixes CVE-2012-4559 and CVE-2012-466[0-2])

* Sat Sep 17 2011 fwang <fwang> 1:0.5.2-1.mga2
+ Revision: 144506
- new version 0.5.2

* Wed Sep 14 2011 tv <tv> 1:0.5.1-1.mga2
+ Revision: 143340
- fix file list
- new release

* Mon Jul 04 2011 dmorgan <dmorgan> 1:0.5.0-1.mga2
+ Revision: 118347
- Fix spec file
  Clean spec file

* Sat Jan 15 2011 mikala <mikala> 1:0.4.7-1.mga1
+ Revision: 18635
- Remove BuildRoot
- imported package libssh

